summaryrefslogtreecommitdiffstats
path: root/ktnef/gui/qwmf.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
commit67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7 (patch)
tree5f52a9eada2e9f3654fc327d7c14dfef570a6ecb /ktnef/gui/qwmf.h
parent2ee4bf4fd5eff93b2fbef0ff8e8063edffc5da5c (diff)
downloadtdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.tar.gz
tdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.zip
Initial conversion of kdepim to TQt
This will probably require some tweaking before it will build under Qt4, however Qt3 builds are OK. Any alterations this commit makes to kdepim behaviour under Qt3 are unintentional and should be fixed. git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1227832 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'ktnef/gui/qwmf.h')
-rw-r--r--ktnef/gui/qwmf.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/ktnef/gui/qwmf.h b/ktnef/gui/qwmf.h
index 5717b393..2ac861d7 100644
--- a/ktnef/gui/qwmf.h
+++ b/ktnef/gui/qwmf.h
@@ -37,21 +37,21 @@ class WinObjBrushHandle;
struct WmfPlaceableHeader;
/**
* QWinMetaFile is a WMF viewer based on QT toolkit
* How to use QWinMetaFile :
* #include "qwmf.h"
- * QWinMetaFile wmf;
+ * TQWinMetaFile wmf;
* TQPicture pic; // or TQImage pic;
* if ( wmf.load( filename )
*   wmf.paint( &pic );
*/
-class QWinMetaFile
+class TQWinMetaFile
{
public:
- QWinMetaFile();
- virtual ~QWinMetaFile();
+ TQWinMetaFile();
+ virtual ~TQWinMetaFile();
/**
* Load WMF file. Returns true on success.
@@ -60,7 +60,7 @@ public:
virtual bool load( TQBuffer &buffer );
/**
- * Paint metafile to given paint-device using absolute or relative coordinate.
+ * Paint metafile to given paint-tqdevice using absolute or relative coordinate.
* abosute coord. reset the world transfomation Matrix
* relative coord. use the existing world transfomation Matrix
* Returns true on success.
@@ -124,9 +124,9 @@ public: // should be protected but cannot
void setPixel( long num, short* parms );
// Set raster operation mode
void setRop( long num, short* parms );
- /* save device context */
+ /* save tqdevice context */
void saveDC( long num, short* parms );
- /* restore device context */
+ /* restore tqdevice context */
void restoreDC( long num, short* parms );
/* clipping region is the intersection of this region and the original region */
void intersectClipRect( long num, short* parms );
@@ -198,8 +198,8 @@ protected:
void deleteHandle( int );
/** Convert windows rasterOp in QT rasterOp */
- Qt::RasterOp winToQtRaster( short parm ) const;
- Qt::RasterOp winToQtRaster( long parm ) const;
+ TQt::RasterOp winToTQtRaster( short parm ) const;
+ TQt::RasterOp winToTQtRaster( long parm ) const;
/** Converts DIB to BMP */
bool dibToBmp( TQImage& bmp, const char* dib, long size);
@@ -37,21 +37,21 @@ class WinObjBrushHandle;
struct WmfPlaceableHeader;
/**
- * QWinMetaFile is a WMF viewer based on QT toolkit
- * How to use QWinMetaFile :
+ * TQWinMetaFile is a WMF viewer based on QT toolkit
+ * How to use TQWinMetaFile :
* #include "qwmf.h"